@@ -17,7 +17,7 @@ class TokenizerWs : public Tokenizer {
 public:
   TokenizerWs(
       std::vector<std::string> NA = std::vector<std::string>(1, "NA"),
-      std::string comment = "",
+      const std::string& comment = "",
       bool skipEmptyRows = true);
 
   void tokenize(SourceIterator begin, SourceIterator end);
