@@ -31,6 +31,7 @@ test_that("col_names expanded to match col_types, with skipping", {
 })
 
 test_that("col_types expanded to col_names by guessing", {
+  skip_if(edition_first())
   expect_warning(
     out <- col_spec_standardise("1,2,3\n", c("a", "b", "c"), "ii"),
     "Insufficient `col_types`"
@@ -54,7 +55,6 @@ test_that("col_spec_standardise works properly with 1 row inputs and no header c
 
 test_that("warns about duplicated names", {
   expect_warning(col_spec_standardise("a,a\n1,2"), "Duplicated column names")
-  expect_warning(col_spec_standardise("X2,\n1,2"), "Duplicated column names")
   expect_warning(
     col_spec_standardise("1,2\n1,2", col_names = c("X", "X")),
     "Duplicated column names"
@@ -69,173 +69,23 @@ test_that("warn about missing col names and fill in", {
   )
 })
 
-# Printing ----------------------------------------------------------------
-
-regex_escape <- function(x) {
-  chars <- c("*", ".", "?", "^", "+", "$", "|", "(", ")", "[", "]", "{", "}", "\\")
-  gsub(paste0("([\\", paste0(collapse = "\\", chars), "])"), "\\\\\\1", x, perl = TRUE)
-}
-
-test_that("print(col_spec) with guess_parser", {
-  out <- col_spec_standardise("a,b,c\n1,2,3")
-  expect_output(print(out),
-    regex_escape(
-"cols(
-  a = col_double(),
-  b = col_double(),
-  c = col_double()
-)"))
-})
-
-test_that("print(col_spec) with collector_skip", {
-  out <- cols_only(a = col_integer(), c = col_integer())
-  expect_output(print(out),
-    regex_escape(
-"cols_only(
-  a = col_integer(),
-  c = col_integer()
-)"))
-})
-
-test_that("print(col_spec) with truncated output", {
-  out <- col_spec_standardise("a,b,c\n1,2,3", col_types = cols(.default = "c"))
-  expect_output(print(out, n = 2, condense = FALSE),
-    regex_escape(
-"cols(
-  .default = col_character(),
-  a = col_character(),
-  b = col_character()
-  # ... with 1 more columns
-)"))
-})
-
 test_that("spec object attached to read data", {
+  skip_if(edition_first())
 
-  test_data <- read_csv("basic-df.csv", col_types = NULL, col_names = TRUE, progress = FALSE)
+  test_data <- read_csv(test_path("basic-df.csv"), col_types = NULL, col_names = TRUE)
   sp <- spec(test_data)
   sp$skip <- NULL
 
-  expect_equal(sp,
+  expect_equal(
+    sp,
     cols(
-       a = col_logical(),
-       b = col_double(),
-       c = col_double(),
-       d = col_character()))
-})
-
-
-test_that("print(col_spec) works with dates", {
-  out <- col_spec_standardise("a,b,c\n",
-    col_types = cols(a = col_date(format = "%Y-%m-%d"),
-      b = col_date(),
-      c = col_date()))
-
-  expect_output(print(out),
-    regex_escape(
-"cols(
-  a = col_date(format = \"%Y-%m-%d\"),
-  b = col_date(format = \"\"),
-  c = col_date(format = \"\")
-)"))
-})
-
-test_that("print(col_spec) with unnamed columns", {
-  out <- col_spec_standardise(col_types = "c_c", col_names = c("a", "c"))
-  expect_output(print(out),
-    regex_escape(
-"cols(
-  a = col_character(),
-  col_skip(),
-  c = col_character()
-)"))
-})
-
-test_that("print(cols_only()) prints properly", {
-  out <- cols_only(
-    a = col_character(),
-    c = col_integer())
-  expect_output(print(out),
-    regex_escape(
-"cols_only(
-  a = col_character(),
-  c = col_integer()
-)"))
-})
-
-test_that("print(col_spec) with n == 0 prints nothing", {
-  out <- col_spec_standardise("a,b,c\n1,2,3")
-  expect_silent(print(out, n = 0))
-})
-
-test_that("print(col_spec, condense = TRUE) condenses the spec", {
-  out <- col_spec_standardise("a,b,c,d\n1,2,3,a")
-  expect_output(print(cols_condense(out)),
-    regex_escape(
-"cols(
-  .default = col_double(),
-  d = col_character()
-)"))
-
-  out <- col_spec_standardise("a,b,c,d\n1,2,3,4")
-  expect_output(print(cols_condense(out)),
-    regex_escape(
-"cols(
-  .default = col_double()
-)"))
-})
-
-test_that("print(col_spec) with no columns specified", {
-  out <- cols()
-  expect_output(print(out), regex_escape("cols()"))
-
-  out <- cols(.default = col_character())
-  expect_output(print(out), regex_escape(
-"cols(
-  .default = col_character()
-)"))
-})
-
-test_that("print(col_spec) and condense edge cases", {
-  out <- cols(a = col_integer(), b = col_integer(), c = col_double())
-
-  expect_equal(format(out, n = 1, condense = TRUE, colour = FALSE),
-"cols(
-  .default = col_integer(),
-  c = col_double()
-)
-")
-})
-
-test_that("print(col_spec) with colors", {
-  out <- col_spec_standardise(
-    "a,b,c,d,e,f,g,h,i\n1,2,F,a,2018-01-01,2018-01-01 12:01:01,12:01:01,foo,blah"
-    , col_types = c(b = "i", h = "f", i = "_")
+      .delim = ",",
+      a = col_logical(),
+      b = col_double(),
+      c = col_double(),
+      d = col_character()
+    )
   )
-
-  with_crayon(
-    expect_known_output(out, "colour-test", print = TRUE)
-  )
-})
-
-test_that("non-syntatic names are escaped", {
-  x <- read_csv("a b,_c,1,a`b\n1,2,3,4")
-  expect_equal(format(spec(x), colour = FALSE),
-"cols(
-  `a b` = col_double(),
-  `_c` = col_double(),
-  `1` = col_double(),
-  `a\\`b` = col_double()
-)
-")
-})
-
-test_that("long expressions are wrapped (597)", {
-  expect_equal(format(cols(a = col_factor(levels = c("apple", "pear", "banana", "peach", "apricot", "orange", "plum"), ordered = TRUE)), colour = FALSE),
-'cols(
-  a = col_factor(levels = c("apple", "pear", "banana", "peach", "apricot", "orange", "plum"
-    ), ordered = TRUE, include_na = FALSE)
-)
-')
 })
 
 test_that("guess_types errors on invalid inputs", {
@@ -276,3 +126,129 @@ test_that("as.character() works on col_spec objects", {
   spec <- as.col_spec(iris)
   expect_equal(as.character(spec), "ddddf")
 })
+
+# Printing ----------------------------------------------------------------
+
+test_that("print(col_spec) with guess_parser", {
+  expect_snapshot(col_spec_standardise("a,b,c\n1,2,3"))
+})
+
+test_that("print(col_spec) with collector_skip", {
+  expect_snapshot(cols_only(a = col_integer(), c = col_integer()))
+})
+
+test_that("print(col_spec) with truncated output", {
+  out <- col_spec_standardise("a,b,c\n1,2,3", col_types = cols(.default = "c"))
+  expect_snapshot(
+    print(out, n = 2, condense = FALSE)
+  )
+})
+
+test_that("print(col_spec) works with dates", {
+  out <- col_spec_standardise("a,b,c\n",
+    col_types = cols(
+      a = col_date(format = "%Y-%m-%d"),
+      b = col_date(),
+      c = col_date()
+    )
+  )
+  expect_snapshot(out)
+})
+
+test_that("print(col_spec) with unnamed columns", {
+  expect_snapshot(
+    col_spec_standardise(col_types = "c_c", col_names = c("a", "c"))
+  )
+})
+
+test_that("print(cols_only()) prints properly", {
+  expect_snapshot(
+    cols_only(a = col_character(), c = col_integer())
+  )
+})
+
+test_that("print(col_spec) with n == 0 prints nothing", {
+  expect_silent(print(col_spec_standardise("a,b,c\n1,2,3"), n = 0))
+})
+
+test_that("print(cols_condense(col_spec)) condenses the spec", {
+  expect_snapshot(
+    cols_condense(col_spec_standardise("a,b,c,d\n1,2,3,a"))
+  )
+  expect_snapshot(
+    cols_condense(col_spec_standardise("a,b,c,d\n1,2,3,4"))
+  )
+})
+
+test_that("print(col_spec) with no columns specified", {
+  expect_snapshot(cols())
+  expect_snapshot(cols(.default = col_character()))
+})
+
+test_that("print(col_spec) and condense edge cases", {
+  expect_snapshot(print(
+    cols(a = col_integer(), b = col_integer(), c = col_double()),
+    n = 1,
+    condense = TRUE,
+    colour = FALSE
+  ))
+})
+
+test_that("print(col_spec) with colors", {
+  local_reproducible_output(crayon = TRUE)
+
+  out <- col_spec_standardise(
+    "a,b,c,d,e,f,g,h,i\n1,2,F,a,2018-01-01,2018-01-01 12:01:01,12:01:01,foo,blah",
+    col_types = c(b = "i", h = "f", i = "_")
+  )
+  expect_snapshot_output(out)
+})
+
+test_that("non-syntatic names are escaped", {
+  expect_snapshot(
+    col_spec_standardise("a b,_c,1,a`b\n1,2,3,4")
+  )
+})
+
+# https://github.com/tidyverse/readr/issues/597
+test_that("long spec declarations can be formatted", {
+  expect_snapshot(
+    cols(a = col_factor(
+      levels = c("apple", "pear", "banana", "peach", "apricot", "orange", "plum"),
+      ordered = TRUE
+    ))
+  )
+})
+
+test_that("options(readr.show_col_types) controls col spec printing", {
+  # skip is temporarily necessary as of January 29 2022, due to the very
+  # recent release of rlang 1.0.0
+  # Windows binaries aren't available yet and the different rlang versions
+  # make it challenging to form test snapshots that work for whole GHA
+  # build matrix
+  skip_if_edition_first_windows()
+
+  withr::local_options(list(readr.show_col_types = TRUE))
+  expect_snapshot(
+    out <- read_csv(readr_example("mtcars.csv")),
+    variant = edition_variant()
+  )
+
+  withr::local_options(list(readr.show_col_types = FALSE))
+  expect_silent(out <- read_csv(readr_example("mtcars.csv")))
+})
+
+test_that("`show_col_types` controls col spec printing", {
+  # skip is temporarily necessary as of January 29 2022, due to the very
+  # recent release of rlang 1.0.0
+  # Windows binaries aren't available yet and the different rlang versions
+  # make it challenging to form test snapshots that work for whole GHA
+  # build matrix
+  skip_if_edition_first_windows()
+
+  expect_snapshot(
+    out <- read_csv(readr_example("mtcars.csv"), show_col_types = TRUE),
+    variant = edition_variant()
+  )
+  expect_silent(out <- read_csv(readr_example("mtcars.csv"), show_col_types = FALSE))
+})
